Succession
==========
A python library providing concurrent push based lazy linked lists.


Installation
------------
Recommended method is to use the version from `pypi`_

.. code::

    pip install succession


Links
-----
  - Source code: https://github.com/bwhmather/succession
  - Issue tracker: https://github.com/bwhmather/succession/issues
  - Continuous integration: https://travis-ci.org/bwhmather/succession
  - PyPI: https://pypi.python.org/pypi/succession


License
-------
The project is licensed under the BSD license.  See `LICENSE`_ for details.


.. _pypi: https://pypi.python.org/pypi/sucession
.. _LICENSE: ./LICENSE
